Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FollowerMetrics ¶
type FollowerOptions ¶
type LogFollower ¶
type LogFollower struct {
// contains filtered or unexported fields
}
func NewLogFollower ¶
func NewLogFollower( docs repository.Documents, opts FollowerOptions, ) *LogFollower
NewLogFollower creates a new follower
func (*LogFollower) GetNext ¶
func (lf *LogFollower) GetNext( ctx context.Context, ) ([]*repository.EventlogItem, error)
func (*LogFollower) GetState ¶
func (lf *LogFollower) GetState() (int64, bool)
GetState returns the current log position and a boolean that is we have caught up with the log and have switched from the compacted log to streaming the eventlog.
type PrometheusFollowerMetrics ¶
type PrometheusFollowerMetrics struct {
// contains filtered or unexported fields
}
func NewPrometheusFollowerMetrics ¶
func NewPrometheusFollowerMetrics( reg prometheus.Registerer, followerName string, ) (*PrometheusFollowerMetrics, error)
func (*PrometheusFollowerMetrics) SetPosition ¶
func (p *PrometheusFollowerMetrics) SetPosition(state string, position int64)
SetPosition implements FollowerMetrics.
Click to show internal directories.
Click to hide internal directories.